@@ -21,10 +21,7 @@ import broadworks_ocip.responses
 import broadworks_ocip.types
 from broadworks_ocip.exceptions import OCIErrorTimeOut
 
-
-FORMATTER = logging.Formatter(
-    "%(asctime)s — %(name)s — %(levelname)s — %(funcName)s:%(lineno)d — %(message)s",
-)
+VERBOSE_DEBUG = 9
 
 
 class BroadworksAPI(Class):
@@ -102,11 +99,10 @@ class BroadworksAPI(Class):
         """
         Create and configure a logging object
         """
-        logger = logging.getLogger("broadworks_api")
+        logger = logging.getLogger(__name__)
         logger.setLevel(logging.WARNING)
         console_handler = logging.StreamHandler(sys.stdout)
         console_handler.setLevel(logging.WARNING)
-        console_handler.setFormatter(FORMATTER)
         logger.addHandler(console_handler)
         self.logger = logger
 
@@ -175,7 +171,7 @@ class BroadworksAPI(Class):
         """
         self.logger.info(f">>> {command}")
         xml = self.get_command_xml(command, **kwargs)
-        self.logger.debug(f"SEND: {str(xml)}")
+        self.logger.log(VERBOSE_DEBUG, f"SEND: {str(xml)}")
         self.socket.sendall(xml + b"\n")
 
     def receive_response(self):
@@ -201,7 +197,7 @@ class BroadworksAPI(Class):
                     break
             elif not readable and not writable and not exceptional:
                 raise OCIErrorTimeOut(object=self, message="Read timeout")
-        self.logger.debug(f"RECV: {str(content)}")
+        self.logger.log(VERBOSE_DEBUG, f"RECV: {str(content)}")
         return self.decode_xml(content)
 
     def decode_xml(self, xml):
@@ -289,11 +285,11 @@ class BroadworksAPI(Class):
         self.send_command(command, **kwargs)
         return self.receive_response()
 
-    def close(self, close_fast=False):
+    def close(self, no_log=False):
         """
         Close the connection to the OCI-P server
         """
-        if self.authenticated and not close_fast:
+        if self.authenticated and not no_log:
             self.logger.debug("Disconnect by logging out")
             self.send_command(
                 "LogoutRequest",
@@ -302,14 +298,17 @@ class BroadworksAPI(Class):
             )
             self.authenticated = False
         if self.socket:
-            self.socket.shutdown(socket.SHUT_RDWR)
-            self.socket.close()
-            if not close_fast:
+            try:
+                self.socket.shutdown(socket.SHUT_RDWR)
+                self.socket.close()
+            except OSError:
+                pass  # we just ignore this under these circumstances
+            if not no_log:
                 self.logger.info(f"Disconnected from host={self.host} port={self.port}")
             self.socket = None
 
     def __del__(self):
-        self.close(close_fast=True)
+        self.close(no_log=True)
 
 
 # end
